===============================
PgColorBar
===============================

PgColorbar is a color bar (legend) for [PyQtGraph](http://www.pyqtgraph.org/) image plots. It can serve as a replacement for PyQtGraph's HistogramLUTItem.

For more info, see: https://github.com/titusjan/pgcolorbar
